pub struct BrowserExecutor;Expand description
Browser protocol executor.
Supports two modes:
- Ephemeral (
session_idisNone): launches Chrome, opens a fresh page, runs the steps, then closes Chrome. - Session (
session_idisSome): acquires an advisory lock on the session file, reconnects to an existing Chrome instance if it is still alive, otherwise launches a fresh one; runs the steps; updates the session file.