Module launcher

Module launcher 

Functions

chrome_binary_candidates
Platform-ordered list of Chrome binary candidates.
configure_page
Apply Earl’s default page configuration after a page is created.
connect_chrome
Connect to an existing Chrome instance by WebSocket (or HTTP debug) URL.
find_chrome
Find the Chrome binary, returning the first path that exists.
launch_chrome
Launch a new Chrome/Chromium instance and return the connected Browser.