pub struct BrowserOperationTemplate {
pub browser: BrowserTemplate,
}Fields
browser: BrowserTemplateTrait Implementations
Sourceimpl Archive for BrowserOperationTemplatewhere
BrowserTemplate: Archive,
impl Archive for BrowserOperationTemplatewhere
BrowserTemplate: Archive,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedBrowserOperationTemplate
type Archived = ArchivedBrowserOperationTemplate
The archived representation of this type. Read more
Sourcetype Resolver = BrowserOperationTemplateResolver
type Resolver = BrowserOperationTemplateResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for BrowserOperationTemplate
impl Clone for BrowserOperationTemplate
Sourcefn clone(&self) -> BrowserOperationTemplate
fn clone(&self) -> BrowserOperationTemplate
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BrowserOperationTemplate
impl Debug for BrowserOperationTemplate
Sourceimpl<'de> Deserialize<'de> for BrowserOperationTemplate
impl<'de> Deserialize<'de> for BrowserOperationTemplate
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<__D: Fallible + ?Sized> Deserialize<BrowserOperationTemplate, __D> for Archived<BrowserOperationTemplate>where
BrowserTemplate: Archive,
<BrowserTemplate as Archive>::Archived: Deserialize<BrowserTemplate, __D>,
impl<__D: Fallible + ?Sized> Deserialize<BrowserOperationTemplate, __D> for Archived<BrowserOperationTemplate>where
BrowserTemplate: Archive,
<BrowserTemplate as Archive>::Archived: Deserialize<BrowserTemplate, __D>,
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<BrowserOperationTemplate, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<BrowserOperationTemplate, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl Serialize for BrowserOperationTemplate
impl Serialize for BrowserOperationTemplate
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for BrowserOperationTemplatewhere
BrowserTemplate: Serialize<__S>,
impl<__S: Fallible + ?Sized> Serialize<__S> for BrowserOperationTemplatewhere
BrowserTemplate: Serialize<__S>,