pub struct PreparedBrowserCommand {
pub session_id: Option<String>,
pub headless: bool,
pub timeout_ms: u64,
pub on_failure_screenshot: bool,
pub steps: Vec<BrowserStep>,
}Expand description
Prepared browser command data, ready for execution.
Fields
session_id: Option<String>headless: booltimeout_ms: u64on_failure_screenshot: boolsteps: Vec<BrowserStep>Trait Implementations
Sourceimpl Archive for PreparedBrowserCommand
impl Archive for PreparedBrowserCommand
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedPreparedBrowserCommand
type Archived = ArchivedPreparedBrowserCommand
The archived representation of this type. Read more
Sourcetype Resolver = PreparedBrowserCommandResolver
type Resolver = PreparedBrowserCommandResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for PreparedBrowserCommand
impl Clone for PreparedBrowserCommand
Sourcefn clone(&self) -> PreparedBrowserCommand
fn clone(&self) -> PreparedBrowserCommand
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PreparedBrowserCommand
impl Debug for PreparedBrowserCommand
Sourceimpl<__D: Fallible + ?Sized> Deserialize<PreparedBrowserCommand, __D> for Archived<PreparedBrowserCommand>where
Option<String>: Archive,
<Option<String> as Archive>::Archived: Deserialize<Option<String>, __D>,
bool: Archive,
<bool as Archive>::Archived: Deserialize<bool, __D>,
u64: Archive,
<u64 as Archive>::Archived: Deserialize<u64, __D>,
Vec<BrowserStep>: Archive,
<Vec<BrowserStep> as Archive>::Archived: Deserialize<Vec<BrowserStep>, __D>,
impl<__D: Fallible + ?Sized> Deserialize<PreparedBrowserCommand, __D> for Archived<PreparedBrowserCommand>where
Option<String>: Archive,
<Option<String> as Archive>::Archived: Deserialize<Option<String>, __D>,
bool: Archive,
<bool as Archive>::Archived: Deserialize<bool, __D>,
u64: Archive,
<u64 as Archive>::Archived: Deserialize<u64, __D>,
Vec<BrowserStep>: Archive,
<Vec<BrowserStep> as Archive>::Archived: Deserialize<Vec<BrowserStep>, __D>,
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<PreparedBrowserCommand, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<PreparedBrowserCommand, <__D as Fallible>::Error>
Deserializes using the given deserializer