Functions
- chrome_
binary_ candidates - Platform-ordered list of Chrome binary candidates.
- configure_
page - Apply Earl’s default page configuration after a page is created.
- connect_
chrome - Connect to an existing Chrome instance by WebSocket (or HTTP debug) URL.
- find_
chrome - Find the Chrome binary, returning the first path that exists.
- launch_
chrome - Launch a new Chrome/Chromium instance and return the connected
Browser.